mathjax: A JavaScript library for displaying mathematical formulas
==================================================================

Description
-----------

MathJax is a JavaScript library for displaying mathematical formulas.

MathJax is used by the Jupyter notebook and the Sphinx documentation.

License
-------

Apache License, version 2.0


Upstream Contact
----------------

Home page: https://www.mathjax.org/

Dependencies
------------

None.


Special Update/Build Instructions
---------------------------------

None.

Patches
-------

-  nopng_config.patch: prevent font warning messages since png files are
   removed. See section "Trimming II -- not strictly necessary" of
   https://github.com/mathjax/MathJax-docs/wiki/Guide%3A-reducing-size-of-a-mathjax-installation
